==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/players/mplayer/mplayerconfigwidget.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "mplayerconfigwidget.h"
#include "mplayerconfigdefs.h"

#include <qlayout.h>
#include <qgroupbox.h>
#include <qcheckbox.h>
#include <qlabel.h>
#include <qwhatsthis.h>

#include <klocale.h>
#include <kcombobox.h>
#include <knuminput.h>
#include <kurlrequester.h>

using namespace SubtitleComposer;

MPlayerConfigWidget::MPlayerConfigWidget( const AppConfigGroup& configGroup, QWidget* parent ):
	AppConfigGroupWidget( configGroup, parent )
{
	QGroupBox* generalGroupBox = createGroupBox( i18n( "General" ) );

	QLabel* pathLabel = new QLabel( generalGroupBox );
	pathLabel->setText( i18n( "Executable path" ) );

	m_pathUrlRequester = new KURLRequester( generalGroupBox );
 	m_pathUrlRequester->setCaption( i18n( "Select the MPlayer executable" ) );
	m_pathUrlRequester->setMode( KFile::File|KFile::ExistingOnly|KFile::LocalOnly );
	m_pathUrlRequester->setURL( "mplayer" );

	QGroupBox* videoGroupBox = createGroupBox( i18n( "Video" ) );

	m_videoOutputCheckBox = new QCheckBox( videoGroupBox );
	m_videoOutputCheckBox->setText( i18n( "Video output driver" ) );

	m_videoOutputComboBox = new KComboBox( false, videoGroupBox );
	m_videoOutputComboBox->setEnabled( false );
	m_videoOutputComboBox->setEditable( true );
	m_videoOutputComboBox->insertStringList( QStringList::split( ' ', "xv xvmc x11 gl gl2 sdl tdfxfb s3fb xover dga ggi fbdev fbdev2 v4l2 bl directfb dfbmga null" ) );

	m_frameDropCheckBox = new QCheckBox( videoGroupBox );
	m_frameDropCheckBox->setText( i18n( "Allow frame dropping" ) );

	m_hardFrameDropCheckBox = new QCheckBox( videoGroupBox );
	m_hardFrameDropCheckBox->setText( i18n( "Allow hard frame dropping" ) );


	QGroupBox* audioGroupBox = createGroupBox( i18n( "Audio" ) );

	m_audioOutputCheckBox = new QCheckBox( audioGroupBox );
	m_audioOutputCheckBox->setText( i18n( "Audio output driver" ) );

	m_audioOutputComboBox = new KComboBox( false, audioGroupBox );
	m_audioOutputComboBox->setEnabled( false );
	m_audioOutputComboBox->setEditable( true );
	m_audioOutputComboBox->insertStringList( QStringList::split( ' ', "alsa oss esd jack nas sdl openal v4l2 null" ) );

	m_avsyncCheckBox = new QCheckBox( audioGroupBox );
	m_avsyncCheckBox->setText( i18n( "A/V synchronization factor" ) );

	m_avsyncSpinBox = new KIntSpinBox( audioGroupBox );
	m_avsyncSpinBox->setEnabled( false );
	m_avsyncSpinBox->setMinValue( 0 );
	m_avsyncSpinBox->setMaxValue( 50 );

	m_volumeNormalizationCheckBox = new QCheckBox( audioGroupBox );
	m_volumeNormalizationCheckBox->setText( i18n( "Volume normalization" ) );


	QGridLayout* generalLayout = createGridLayout( generalGroupBox );
	generalLayout->addWidget( pathLabel, 0, 0 );
	generalLayout->addWidget( m_pathUrlRequester, 0, 1 );

	QGridLayout* audioLayout = createGridLayout( audioGroupBox );
	audioLayout->addWidget( m_audioOutputCheckBox, 0, 0 );
	audioLayout->addWidget( m_audioOutputComboBox, 0, 1 );
	audioLayout->addWidget( m_avsyncCheckBox, 1, 0 );
	audioLayout->addWidget( m_avsyncSpinBox, 1, 1 );
	audioLayout->addWidget( m_volumeNormalizationCheckBox, 2, 0 );

	QGridLayout* videoLayout = createGridLayout( videoGroupBox );
	videoLayout->addWidget( m_videoOutputCheckBox, 0, 0 );
	videoLayout->addWidget( m_videoOutputComboBox, 0, 1 );
	videoLayout->addWidget( m_frameDropCheckBox, 1, 0 );
	videoLayout->addWidget( m_hardFrameDropCheckBox, 2, 0 );


	connect( m_audioOutputCheckBox, SIGNAL( toggled(bool) ), m_audioOutputComboBox, SLOT( setEnabled(bool) ) );
	connect( m_avsyncCheckBox, SIGNAL( toggled(bool) ), m_avsyncSpinBox, SLOT( setEnabled(bool) ) );
	connect( m_videoOutputCheckBox, SIGNAL( toggled(bool) ), m_videoOutputComboBox, SLOT( setEnabled(bool) ) );

	connect( m_pathUrlRequester, SIGNAL( textChanged(const QString&) ), this, SIGNAL( settingsChanged() ) );
	connect( m_audioOutputCheckBox, SIGNAL( toggled(bool) ), this, SIGNAL( settingsChanged() ) );
	connect( m_avsyncCheckBox, SIGNAL( toggled(bool) ), this, SIGNAL( settingsChanged() ) );
	connect( m_volumeNormalizationCheckBox, SIGNAL( toggled(bool) ), this, SIGNAL( settingsChanged() ) );
	connect( m_videoOutputCheckBox, SIGNAL( toggled(bool) ), this, SIGNAL( settingsChanged() ) );
	connect( m_frameDropCheckBox, SIGNAL( toggled(bool) ), this, SIGNAL( settingsChanged() ) );
	connect( m_hardFrameDropCheckBox, SIGNAL( toggled(bool) ), this, SIGNAL( settingsChanged() ) );
	connect( m_audioOutputComboBox, SIGNAL( textChanged(const QString&) ), this, SIGNAL( settingsChanged() ) );
	connect( m_avsyncSpinBox, SIGNAL( valueChanged(int) ), this, SIGNAL( settingsChanged() ) );
	connect( m_videoOutputComboBox, SIGNAL( textChanged(const QString&) ), this, SIGNAL( settingsChanged() ) );

	setControlsFromConfig();
}

MPlayerConfigWidget::~MPlayerConfigWidget()
{
}

void MPlayerConfigWidget::setConfigFromControls()
{
	m_configGroup.setOption( OPT_EXEC_PATH, m_pathUrlRequester->url() );

	m_configGroup.setOption( OPT_AO, m_audioOutputCheckBox->isChecked() ? m_audioOutputComboBox->currentText() : QString::null );
	m_configGroup.setOption( OPT_VOLUME_NORM, m_volumeNormalizationCheckBox->isChecked() );
	m_configGroup.setOption( OPT_AUTOSYNC_FACTOR, m_avsyncCheckBox->isChecked() ? QString::number( m_avsyncSpinBox->value() ) : QString::null );

	m_configGroup.setOption( OPT_VO, m_videoOutputCheckBox->isChecked() ? m_videoOutputComboBox->currentText() : QString::null );
	m_configGroup.setOption( OPT_FRAME_DROP, m_frameDropCheckBox->isChecked() );
	m_configGroup.setOption( OPT_HARD_FRAME_DROP, m_hardFrameDropCheckBox->isChecked() );
}

void MPlayerConfigWidget::setControlsFromConfig()
{
	m_pathUrlRequester->setURL( m_configGroup.option( OPT_EXEC_PATH ) );

	QString value = m_configGroup.option( OPT_AO );
	m_audioOutputCheckBox->setChecked( ! value.isEmpty() );
	if ( ! value.isEmpty() )
		m_audioOutputComboBox->setEditText( value );

	m_volumeNormalizationCheckBox->setChecked( m_configGroup.optionAsBool( OPT_VOLUME_NORM ) );

	value = m_configGroup.option( OPT_AUTOSYNC_FACTOR );
	m_avsyncCheckBox->setChecked( ! value.isEmpty() );
	if ( ! value.isEmpty() )
		m_avsyncSpinBox->setValue( value.toInt() );

	value = m_configGroup.option( OPT_VO );
	m_videoOutputCheckBox->setChecked( ! value.isEmpty() );
	if ( ! value.isEmpty() )
		m_videoOutputComboBox->setEditText( value );

	m_frameDropCheckBox->setChecked( m_configGroup.optionAsBool( OPT_FRAME_DROP ) );
	m_hardFrameDropCheckBox->setChecked( m_configGroup.optionAsBool( OPT_HARD_FRAME_DROP ) );
}

#include "mplayerconfigwidget.moc"

==> subtitlecomposer-0.4.2.tar.bz2: subtitlecomposer-0.4.2/src/players/mplayer/mplayerconfigwidget.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "mplayerconfigwidget.h"
#include "mplayerconfigdefs.h"

#include <qlayout.h>
#include <qgroupbox.h>
#include <qcheckbox.h>
#include <qlabel.h>
#include <qwhatsthis.h>

#include <klocale.h>
#include <kcombobox.h>
#include <knuminput.h>
#include <kurlrequester.h>

using namespace SubtitleComposer;

MPlayerConfigWidget::MPlayerConfigWidget( const AppConfigGroup& configGroup, QWidget* parent ):
	AppConfigGroupWidget( configGroup, parent )
{
	QGroupBox* generalGroupBox = createGroupBox( i18n( "General" ) );

	QLabel* pathLabel = new QLabel( generalGroupBox );
	pathLabel->setText( i18n( "Executable path" ) );

	m_pathURLRequester = new KURLRequester( generalGroupBox );
 	m_pathURLRequester->setCaption( i18n( "Select the MPlayer executable" ) );
	m_pathURLRequester->setMode( KFile::File|KFile::ExistingOnly|KFile::LocalOnly );
	m_pathURLRequester->setURL( "mplayer" );

	QGroupBox* videoGroupBox = createGroupBox( i18n( "Video" ) );

	m_videoOutputCheckBox = new QCheckBox( videoGroupBox );
	m_videoOutputCheckBox->setText( i18n( "Video output driver" ) );

	m_videoOutputComboBox = new KComboBox( false, videoGroupBox );
	m_videoOutputComboBox->setEnabled( false );
	m_videoOutputComboBox->setEditable( true );
	m_videoOutputComboBox->insertStringList( QStringList::split( ' ', "xv xvmc x11 gl gl2 sdl tdfxfb s3fb xover dga ggi fbdev fbdev2 v4l2 bl directfb dfbmga null" ) );

	m_frameDropCheckBox = new QCheckBox( videoGroupBox );
	m_frameDropCheckBox->setText( i18n( "Allow frame dropping" ) );

	m_hardFrameDropCheckBox = new QCheckBox( videoGroupBox );
	m_hardFrameDropCheckBox->setText( i18n( "Allow hard frame dropping" ) );


	QGroupBox* audioGroupBox = createGroupBox( i18n( "Audio" ) );

	m_audioOutputCheckBox = new QCheckBox( audioGroupBox );
	m_audioOutputCheckBox->setText( i18n( "Audio output driver" ) );

	m_audioOutputComboBox = new KComboBox( false, audioGroupBox );
	m_audioOutputComboBox->setEnabled( false );
	m_audioOutputComboBox->setEditable( true );
	m_audioOutputComboBox->insertStringList( QStringList::split( ' ', "alsa oss esd jack nas sdl openal v4l2 null" ) );

	m_avsyncCheckBox = new QCheckBox( audioGroupBox );
	m_avsyncCheckBox->setText( i18n( "A/V synchronization factor" ) );

	m_avsyncSpinBox = new KIntSpinBox( audioGroupBox );
	m_avsyncSpinBox->setEnabled( false );
	m_avsyncSpinBox->setMinValue( 0 );
	m_avsyncSpinBox->setMaxValue( 50 );

	m_volumeNormalizationCheckBox = new QCheckBox( audioGroupBox );
	m_volumeNormalizationCheckBox->setText( i18n( "Volume normalization" ) );


	QGridLayout* generalLayout = createGridLayout( generalGroupBox );
	generalLayout->addWidget( pathLabel, 0, 0 );
	generalLayout->addWidget( m_pathURLRequester, 0, 1 );

	QGridLayout* audioLayout = createGridLayout( audioGroupBox );
	audioLayout->addWidget( m_audioOutputCheckBox, 0, 0 );
	audioLayout->addWidget( m_audioOutputComboBox, 0, 1 );
	audioLayout->addWidget( m_avsyncCheckBox, 1, 0 );
	audioLayout->addWidget( m_avsyncSpinBox, 1, 1 );
	audioLayout->addWidget( m_volumeNormalizationCheckBox, 2, 0 );

	QGridLayout* videoLayout = createGridLayout( videoGroupBox );
	videoLayout->addWidget( m_videoOutputCheckBox, 0, 0 );
	videoLayout->addWidget( m_videoOutputComboBox, 0, 1 );
	videoLayout->addWidget( m_frameDropCheckBox, 1, 0 );
	videoLayout->addWidget( m_hardFrameDropCheckBox, 2, 0 );


	connect( m_audioOutputCheckBox, SIGNAL( toggled(bool) ), m_audioOutputComboBox, SLOT( setEnabled(bool) ) );
	connect( m_avsyncCheckBox, SIGNAL( toggled(bool) ), m_avsyncSpinBox, SLOT( setEnabled(bool) ) );
	connect( m_videoOutputCheckBox, SIGNAL( toggled(bool) ), m_videoOutputComboBox, SLOT( setEnabled(bool) ) );

	connect( m_pathURLRequester, SIGNAL( textChanged(const QString&) ), this, SIGNAL( settingsChanged() ) );
	connect( m_audioOutputCheckBox, SIGNAL( toggled(bool) ), this, SIGNAL( settingsChanged() ) );
	connect( m_avsyncCheckBox, SIGNAL( toggled(bool) ), this, SIGNAL( settingsChanged() ) );
	connect( m_volumeNormalizationCheckBox, SIGNAL( toggled(bool) ), this, SIGNAL( settingsChanged() ) );
	connect( m_videoOutputCheckBox, SIGNAL( toggled(bool) ), this, SIGNAL( settingsChanged() ) );
	connect( m_frameDropCheckBox, SIGNAL( toggled(bool) ), this, SIGNAL( settingsChanged() ) );
	connect( m_hardFrameDropCheckBox, SIGNAL( toggled(bool) ), this, SIGNAL( settingsChanged() ) );
	connect( m_audioOutputComboBox, SIGNAL( textChanged(const QString&) ), this, SIGNAL( settingsChanged() ) );
	connect( m_avsyncSpinBox, SIGNAL( valueChanged(int) ), this, SIGNAL( settingsChanged() ) );
	connect( m_videoOutputComboBox, SIGNAL( textChanged(const QString&) ), this, SIGNAL( settingsChanged() ) );

	setControlsFromConfig();
}

MPlayerConfigWidget::~MPlayerConfigWidget()
{
}

void MPlayerConfigWidget::setConfigFromControls()
{
	m_configGroup.setOption( OPT_EXEC_PATH, m_pathURLRequester->url() );

	m_configGroup.setOption( OPT_AO, m_audioOutputCheckBox->isChecked() ? m_audioOutputComboBox->currentText() : QString::null );
	m_configGroup.setOption( OPT_VOLUME_NORM, m_volumeNormalizationCheckBox->isChecked() );
	m_configGroup.setOption( OPT_AUTOSYNC_FACTOR, m_avsyncCheckBox->isChecked() ? QString::number( m_avsyncSpinBox->value() ) : QString::null );

	m_configGroup.setOption( OPT_VO, m_videoOutputCheckBox->isChecked() ? m_videoOutputComboBox->currentText() : QString::null );
	m_configGroup.setOption( OPT_FRAME_DROP, m_frameDropCheckBox->isChecked() );
	m_configGroup.setOption( OPT_HARD_FRAME_DROP, m_hardFrameDropCheckBox->isChecked() );
}

void MPlayerConfigWidget::setControlsFromConfig()
{
	m_pathURLRequester->setURL( m_configGroup.option( OPT_EXEC_PATH ) );

	QString value = m_configGroup.option( OPT_AO );
	m_audioOutputCheckBox->setChecked( ! value.isEmpty() );
	if ( ! value.isEmpty() )
		m_audioOutputComboBox->setEditText( value );

	m_volumeNormalizationCheckBox->setChecked( m_configGroup.optionAsBool( OPT_VOLUME_NORM ) );

	value = m_configGroup.option( OPT_AUTOSYNC_FACTOR );
	m_avsyncCheckBox->setChecked( ! value.isEmpty() );
	if ( ! value.isEmpty() )
		m_avsyncSpinBox->setValue( value.toInt() );

	value = m_configGroup.option( OPT_VO );
	m_videoOutputCheckBox->setChecked( ! value.isEmpty() );
	if ( ! value.isEmpty() )
		m_videoOutputComboBox->setEditText( value );

	m_frameDropCheckBox->setChecked( m_configGroup.optionAsBool( OPT_FRAME_DROP ) );
	m_hardFrameDropCheckBox->setChecked( m_configGroup.optionAsBool( OPT_HARD_FRAME_DROP ) );
}

#include "mplayerconfigwidget.moc"
